@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-__version__ = "0.0.5"
+__version__ = "0.1"
 __description__ = "Python tool for simply adding startup item by systemd."
 __license__ = "MIT"
 __author__ = "DIYer22"
@@ -18,6 +18,7 @@ __classifiers__ = [
 
 import os
 import sys
+import argparse
 
 doc = f"""
 {__description__}
@@ -26,12 +27,11 @@ Install:
     pip install add_service
 
 Usage:
-    python -m add_service [shell_file/cmd] [user (default `whoami`)]
+    python -m add_service shell_file/cmd [--user root(default `whoami`)] [--name service_name] [--start]
 
 Examples:
-    python -m add_service ssh_nat.sh   # service name is ssh_nat.service
-    python -m add_service "`which python3` -m http.server 80" root
-    # service name is add_service0.service
+    python -m add_service ssh_nat.sh   # defaut service name is ssh_nat.service
+    python -m add_service "`which python3` -m http.server 80" --user root --name http_server
 
 See: https://github.com/DIYer22/add_service
 """
@@ -59,27 +59,37 @@ def filename(path):
 
 
 if __name__ == "__main__":
-    args = sys.argv[1:]
+    parser = argparse.ArgumentParser(
+        description=doc, formatter_class=argparse.RawTextHelpFormatter
+    )
+    parser.add_argument("script", help="Executable file or cmd")
+    parser.add_argument("--user", default=execmd("whoami"), help="User")
+    parser.add_argument("--name", default=None, help="Service name")
+    parser.add_argument(
+        "--start", action="store_true", help="Start service immediately"
+    )
+    args = parser.parse_args()
 
-    if len(args) == 0:
-        print(doc)
-        exit(1)
-    elif len(args) == 1:
-        if args[-1] in ["-h", "--help"]:
-            print(doc)
-            exit(0)
-        args.append(execmd("whoami"))
-    # assert os.path.isfile(exec_start)
-    # assert open(exec_start).read().strip().startswith("#!")
+    # args = sys.argv[1:]
 
-    exec_start, user = args
-    if os.path.isfile(exec_start):
-        exec_start = os.path.abspath(exec_start)
-        name = filename(exec_start)
-        assert os.access(exec_start, os.X_OK), f'Please "chmod +x {exec_start}"'
-        if exec_start.endswith(".sh"):
+    # if len(args) == 0:
+    #     print(doc)
+    #     exit(1)
+    # elif len(args) == 1:
+    #     if args[-1] in ["-h", "--help"]:
+    #         print(doc)
+    #         exit(0)
+    #     args.append(execmd("whoami"))
+    # assert os.path.isfile(script)
+    # assert open(script).read().strip().startswith("#!")
+
+    if os.path.isfile(args.script):
+        args.script = os.path.abspath(args.script)
+        name = filename(args.script)
+        assert os.access(args.script, os.X_OK), f'Please "chmod +x {args.script}"'
+        if args.script.endswith(".sh"):
             _msg = '`.sh` file should start with "#!/usr/bin/env bash"'
-            assert open(exec_start).read().strip().startswith("#!"), _msg
+            assert open(args.script).read().strip().startswith("#!"), _msg
     else:
 
         for idx in range(9999):
@@ -87,9 +97,10 @@ if __name__ == "__main__":
             service_path = f"/etc/systemd/system/{name}.service"
             if not os.path.isfile(service_path):
                 break
+    name = args.name or name
 
     dir_path = os.path.abspath(".")
-    group = get_group(user)
+    group = get_group(args.user)
 
     service_path = f"/etc/systemd/system/{name}.service"
     service_name = os.path.basename(service_path)
@@ -102,10 +113,10 @@ Description="{service_name} added by add_service: {args}"
 After=network.service
 [Service]
 Type=simple
-User={user}
+User={args.user}
 Group={group}
 WorkingDirectory={dir_path}
-ExecStart={exec_start}
+ExecStart={args.script}
 PrivateTmp=true
 Restart=on-failure
 [Install]
@@ -122,8 +133,15 @@ WantedBy=multi-user.target
     print(f"Need sudo to create: {service_path}")
     print(f"And exec `sudo systemctl enable {service_name}`")
     cmd = f"""sudo mv "{tmp_path}" "{service_path}" && sudo systemctl enable {service_name}"""
-    # print("Run cmd:")
-    # print("\t"+cmd)
+
+    start_cmd = f"sudo systemctl start {service_name}"
+    if args.start:
+        cmd += " && " + start_cmd
+
+    print("Execute cmd:")
+    print("\t" + cmd)
     assert not os.system(cmd)
-    print("Start service right now by manual:")
-    print(f"\tsudo systemctl start {service_name}")
+
+    if not args.start:
+        print("Start service right now by manual:")
+        print(f"\t{start_cmd}")
